@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: browser.c,v 1.14 1998/10/21 15:40:17 roessler Exp $";
+static const char rcsid[]="$Id: browser.c,v 1.16 1998/11/09 11:06:28 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -172,7 +172,7 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
       }
       break;
     case 'f':
-      strncpy (fn, folder->name, sizeof(fn) - 1);
+      strfcpy (fn, folder->name, sizeof(fn));
       if (folder->f != NULL)
       {
 	strcat (fn, S_ISLNK (folder->f->st_mode) ? "@" : 
@@ -749,23 +749,25 @@ void mutt_select_file (char *f, size_t flen, int buffy)
 	      break;
 
             case 1: /* (d)ate */
-	      BrowserSort = reverse | SORT_DATE;
+	      BrowserSort = SORT_DATE;
 	      break;
 
             case 2: /* (a)lpha */
-	      BrowserSort = reverse | SORT_SUBJECT;
+	      BrowserSort = SORT_SUBJECT;
 	      break;
 
             case 3: /* si(z)e */
-	      BrowserSort = reverse | SORT_SIZE;
+	      BrowserSort = SORT_SIZE;
 	      break;
 
             case 4: /* do(n)'t sort */
 	      BrowserSort = SORT_ORDER;
+	      resort = 0;
 	      break;
 	  }
 	  if (resort)
 	  {
+	    BrowserSort |= reverse ? SORT_REVERSE : 0;
 	    browser_sort (&state);
 	    menu->redraw = REDRAW_FULL;
 	  }
