@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: parse_i18n.c,v 1.5 1998/10/13 20:46:32 roessler Exp $";
+static const char rcsid[]="$Id: parse_i18n.c,v 1.7 1998/10/15 20:34:25 roessler Exp $";
 /*
  * Copyright (C) 1998 Thomas Roessler <roessler@guug.de>
  * 
@@ -344,7 +344,7 @@ int main(int argc, const char *argv[])
        && (basedir ? 0 : strlen(basedir) + 1) 
           + strlen(m->charset) + 1 < sizeof(buffer))
     {
-      sprintf(buffer, "%s%s%s", basedir ? basedir : "", basedir ? "/" : "",
+      snprintf(buffer, sizeof(buffer), "%s%s%s", basedir ? basedir : "", basedir ? "/" : "",
 	       m->charset);
       
       if((fp = fopen(buffer, "w")))
