@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: commands.c,v 1.17 1998/10/28 16:39:55 roessler Exp $";
+static const char rcsid[]="$Id: commands.c,v 1.18 1998/11/10 21:02:20 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -657,7 +657,7 @@ int mutt_save_message (HEADER *h, int delete, int decode, int decrypt, int *redr
       }
     }
 
-    need_buffy_cleanup = (ctx.magic == M_MBOX || ctx.magic == M_MMDF);
+    need_buffy_cleanup = (ctx.magic == M_MBOX || ctx.magic == M_MMDF || ctx.magic == M_KENDRA);
 
     mx_close_mailbox (&ctx);
 
