@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: curs_lib.c,v 1.20 1998/10/28 21:43:27 roessler Exp $";
+static const char rcsid[]="$Id: curs_lib.c,v 1.21 1998/11/10 19:20:14 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -403,7 +403,7 @@ int mutt_multi_choice (char *prompt, char *letters)
   {
     mutt_refresh ();
     ch  = mutt_getch ();
-    if (ch.ch == -1)
+    if (ch.ch == -1 || CI_is_return (ch.ch))
     {
       choice = -1;
       break;
