@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: edit.c,v 1.7 1998/10/15 20:33:22 roessler Exp $";
+static const char rcsid[]="$Id: edit.c,v 1.8 1998/11/10 20:23:29 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -357,7 +357,7 @@ int mutt_builtin_editor (const char *path, HEADER *msg, HEADER *cur)
 	  if (Context)
 	  {
 	    if (!*p && cur)
-	    {
+ 	    {
 	      /* include the current message */
 	      p = tmp + strlen (tmp) + 1;
 	      snprintf (tmp + strlen (tmp), sizeof (tmp) - strlen (tmp), " %d",
@@ -447,7 +447,7 @@ int mutt_builtin_editor (const char *path, HEADER *msg, HEADER *cur)
       done = 1;
     else
     {
-      strcat (tmp, "\n");
+      strncat (tmp, "\n", sizeof(tmp)); tmp[sizeof(tmp) - 1] = '\0';
       if (buflen == bufmax)
 	safe_realloc ((void **)&buf, sizeof (char *) * (bufmax += 25));
       buf[buflen++] = safe_strdup (tmp[1] == '~' ? tmp + 1 : tmp);
