@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: headers.c,v 1.7 1998/10/13 20:45:14 roessler Exp $";
+static const char rcsid[]="$Id: headers.c,v 1.9 1998/10/15 20:33:32 roessler Exp $";
 /* 
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -129,7 +129,7 @@ void mutt_edit_headers (const char *editor,
   /* Read the temp file back in */
   ifp = fopen (path, "r");
   ofp = safe_fopen (body, "w");
-  n = mutt_read_rfc822_header (ifp, NULL);
+  n = mutt_read_rfc822_header (ifp, NULL, 1);
   while ((i = fread (buffer, 1, sizeof (buffer), ifp)) > 0)
     fwrite (buffer, 1, i, ofp);
   fclose (ofp);
