@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: help.c,v 1.8 1998/10/28 16:39:57 roessler Exp $";
+static const char rcsid[]="$Id: help.c,v 1.9 1998/11/09 10:47:17 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -87,14 +87,14 @@ mutt_compile_help (char *buf, size_t buflen, int menu, struct mapping_t *items)
 
 static int print_macro (FILE *f, int maxchar, const char **macro)
 {
-  int c = **macro;
+  int c = (unsigned char) **macro;
   int n = maxchar;
 
   while (c)
   {
     if (!IsPrint(c))
     {
-      if (c >= ' ')
+      if (c >= ' ' && c != 127)
 	c = '?';
       else if (n < 2)
 	c = 0;
@@ -121,7 +121,7 @@ static int print_macro (FILE *f, int maxchar, const char **macro)
 	    break;
 	  default:
 	    fputc ('^', f);
-	    c += '@';
+	    c = (c + '@') & 127;
 	    break;
 	}
       }
