@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: init.c,v 1.20 1998/10/19 08:42:41 roessler Exp $";
+static const char rcsid[]="$Id: init.c,v 1.22 1998/11/10 21:02:23 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -907,6 +907,9 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
 	  case M_MMDF:
 	    p = "MMDF";
 	    break;
+	  case M_KENDRA:
+	    p = "KENDRA";
+	    break;
 	  case M_MH:
 	    p = "MH";
 	    break;
@@ -1402,6 +1405,29 @@ int mutt_var_value_complete (char *buffer, size_t len, int pos)
 	snprintf(pt, dlen, "%s%s", tmp,  vals[quadoption (MuttVars[idx].data)]);
       else if (DTYPE (MuttVars[idx].type) == DT_NUM)
 	snprintf (pt, dlen, "%s%d", tmp, (*((short *) MuttVars[idx].data)));
+      else if (DTYPE (MuttVars[idx].type) == DT_SORT)
+      {
+	const struct mapping_t *map;
+	char *p;
+
+	switch (MuttVars[idx].type & DT_SUBTYPE_MASK)
+	{
+	  case DT_SORT_ALIAS:
+	    map = SortAliasMethods;
+	    break;
+	  case DT_SORT_BROWSER:
+	    map = SortBrowserMethods;
+	    break;
+	  default:
+	    map = SortMethods;
+	    break;
+	}
+	p = mutt_getnamebyvalue (*((short *) MuttVars[idx].data) & SORT_MASK, map);
+	snprintf (pt, dlen, "%s\"%s%s%s\"", tmp,
+		  (*((short *) MuttVars[idx].data) & SORT_REVERSE) ? "reverse-" : "",
+		  (*((short *) MuttVars[idx].data) & SORT_LAST) ? "last-" : "",
+		  p);
+      }
       else
 	return 0;
       return 1;
