@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: main.c,v 1.16 1998/10/15 20:33:41 roessler Exp $";
+static const char rcsid[]="$Id: main.c,v 1.17 1998/11/09 11:07:25 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -672,17 +672,9 @@ int main (int argc, char **argv)
 
     if ((Context = mx_open_mailbox (folder, ((flags & M_RO) || option (OPTREADONLY)) ? M_READONLY : 0, NULL)) != NULL)
     {
-      int close = mutt_index_menu ();
-
+      mutt_index_menu ();
       if (Context)
-      {
-	if (close == OP_QUIT) 
-	  mx_close_mailbox (Context);
-	else
-	  mx_fastclose_mailbox (Context);
-      }
-
-      safe_free ((void **)&Context);
+	safe_free ((void **)&Context);
       mutt_endwin (NULL);
     }
     else
