@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: mbox.c,v 1.9 1998/10/15 20:33:42 roessler Exp $";
+static const char rcsid[]="$Id: mbox.c,v 1.11 1998/11/10 21:02:24 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -19,6 +19,10 @@ static const char rcsid[]="$Id: mbox.c,v 1.9 1998/10/15 20:33:42 roessler Exp $"
 
 /* This file contains code to parse ``mbox'' and ``mmdf'' style mailboxes */
 
+/* OS/2's "kendra" mail folder format is also supported.  It's a slightly
+ * modified version of MMDF.
+ */
+
 #include "mutt.h"
 #include "mailbox.h"
 #include "mx.h"
@@ -106,12 +110,13 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
   tz = mutt_local_tz ();
 
   buf[sizeof (buf) - 1] = 0;
+  
   FOREVER
   {
     if (fgets (buf, sizeof (buf) - 1, ctx->fp) == NULL)
       break;
 
-    if (strcmp (buf, MMDF_SEP) == 0)
+    if (strcmp (buf, ctx->magic == M_MMDF ? MMDF_SEP : KENDRA_SEP) == 0)
     {
       loc = ftell (ctx->fp);
 
@@ -131,7 +136,14 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
       t = is_from (buf, return_path, sizeof (return_path));
 
       if (!t)
-	fseek (ctx->fp, loc, 0);
+      {
+	if (fseek (ctx->fp, loc, SEEK_SET) != 0)
+	{
+	  dprint (1, (debugfile, "mmdf_parse_mailbox: fseek() failed\n"));
+	  mutt_error _("Mailbox is corrupt!");
+	  return (-1);
+	}
+      } 
       else
 	hdr->received = t + tz;
 
@@ -145,11 +157,12 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
 
 	if (tmploc < ctx->size)
 	{
-	  fseek (ctx->fp, tmploc, 0);
-	  if (fgets (buf, sizeof (buf) - 1, ctx->fp) == NULL ||
-	      strcmp (MMDF_SEP, buf) != 0)
+	  if (fseek (ctx->fp, tmploc, SEEK_SET) != 0 ||
+	      fgets (buf, sizeof (buf) - 1, ctx->fp) == NULL ||
+	      strcmp (ctx->magic == M_MMDF ? MMDF_SEP : KENDRA_SEP, buf) != 0)
 	  {
-	    fseek (ctx->fp, loc, 0);
+	    if (fseek (ctx->fp, loc, SEEK_SET) != 0)
+	      dprint (1, (debugfile, "mmdf_parse_mailbox: fseek() failed\n"));
 	    hdr->content->length = -1;
 	  }
 	}
@@ -167,7 +180,7 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
 	  if (fgets (buf, sizeof (buf) - 1, ctx->fp) == NULL)
 	    break;
 	  lines++;
-	} while (strcmp (buf, MMDF_SEP) != 0);
+	} while (strcmp (buf, ctx->magic == M_MMDF ? MMDF_SEP : KENDRA_SEP) != 0);
 
 	hdr->lines = lines;
 	hdr->content->length = loc - hdr->content->offset;
@@ -180,6 +193,8 @@ int mmdf_parse_mailbox (CONTEXT *ctx)
 	hdr->env->from = rfc822_cpy_adr (hdr->env->return_path);
 
       mx_update_context (ctx);
+      if(ctx->magic == M_KENDRA && feof(ctx->fp))
+	break;
     }
     else
     {
@@ -289,13 +304,16 @@ int mbox_parse_mailbox (CONTEXT *ctx)
 	   * check to see if the content-length looks valid.  we expect to
 	   * to see a valid message separator at this point in the stream
 	   */
-	  fseek (ctx->fp, tmploc, 0);
-	  if (fgets (buf, sizeof (buf), ctx->fp) == NULL ||
+	  if (fseek (ctx->fp, tmploc, SEEK_SET) != 0 ||
+	      fgets (buf, sizeof (buf), ctx->fp) == NULL ||
 	      strncmp ("From ", buf, 5) != 0)
 	  {
 	    dprint (1, (debugfile, "mbox_parse_mailbox: bad content-length in message %d (cl=%ld)\n", curhdr->index, curhdr->content->length));
 	    dprint (1, (debugfile, "\tLINE: %s", buf));
-	    fseek (ctx->fp, loc, 0); /* nope, return the previous position */
+	    if (fseek (ctx->fp, loc, SEEK_SET) != 0) /* nope, return the previous position */
+	    {
+	      dprint (1, (debugfile, "mbox_parse_mailbox: fseek() failed\n"));
+	    }
 	    curhdr->content->length = -1;
 	  }
 	}
@@ -317,7 +335,8 @@ int mbox_parse_mailbox (CONTEXT *ctx)
 	    int cl = curhdr->content->length;
 
 	    /* count the number of lines in this message */
-	    fseek (ctx->fp, loc, 0);
+	    if (fseek (ctx->fp, loc, SEEK_SET) != 0)
+	      dprint (1, (debugfile, "mbox_parse_mailbox: fseek() failed\n"));
 	    while (cl-- > 0)
 	    {
 	      if (fgetc (ctx->fp) == '\n')
@@ -326,7 +345,8 @@ int mbox_parse_mailbox (CONTEXT *ctx)
 	  }
 
 	  /* return to the offset of the next message separator */
-	  fseek (ctx->fp, tmploc, 0);
+	  if (fseek (ctx->fp, tmploc, SEEK_SET) != 0)
+	    dprint (1, (debugfile, "mbox_parse_mailbox: fseek() failed\n"));
 	}
       }
 
@@ -389,7 +409,7 @@ int mbox_open_mailbox (CONTEXT *ctx)
 
   if (ctx->magic == M_MBOX)
     rc = mbox_parse_mailbox (ctx);
-  else if (ctx->magic == M_MMDF)
+  else if (ctx->magic == M_MMDF || ctx->magic == M_KENDRA)
     rc = mmdf_parse_mailbox (ctx);
   else
     rc = -1;
@@ -568,13 +588,16 @@ int mbox_check_mailbox (CONTEXT *ctx, int *index_hint)
        * see the message separator at *exactly* what used to be the end of the
        * folder.
        */
-      fseek (ctx->fp, ctx->size, 0);
+      if (fseek (ctx->fp, ctx->size, SEEK_SET) != 0)
+	dprint (1, (debugfile, "mbox_check_mailbox: fseek() failed\n"));
       if (fgets (buffer, sizeof (buffer), ctx->fp) != NULL)
       {
 	if ((ctx->magic == M_MBOX && strncmp ("From ", buffer, 5) == 0) ||
-	    (ctx->magic == M_MMDF && strcmp (MMDF_SEP, buffer) == 0))
+	    (ctx->magic == M_MMDF && strcmp (MMDF_SEP, buffer) == 0) ||
+	    (ctx->magic == M_KENDRA && strcmp(KENDRA_SEP, buffer) == 0))
 	{
-	  fseek (ctx->fp, ctx->size, 0);
+	  if (fseek (ctx->fp, ctx->size, SEEK_SET) != 0)
+	    dprint (1, (debugfile, "mbox_check_mailbox: fseek() failed\n"));
 	  if (ctx->magic == M_MBOX)
 	    mbox_parse_mailbox (ctx);
 	  else
@@ -635,7 +658,7 @@ int mbox_check_mailbox (CONTEXT *ctx, int *index_hint)
 int mbox_sync_mailbox (CONTEXT *ctx)
 {
   char tempfile[_POSIX_PATH_MAX];
-  char buf[16];
+  char buf[32];
   int i, j, save_sort = SORT_ORDER;
   int need_sort = 0; /* flag to resort mailbox if new mail arrives */
   int first;	/* first message to be written */
@@ -643,7 +666,7 @@ int mbox_sync_mailbox (CONTEXT *ctx)
   struct stat statbuf;
   struct utimbuf utimebuf;
   struct m_update_t *newOffset = NULL;
-  FILE *fp;
+  FILE *fp = NULL;
 
   /* sort message by their position in the mailbox on disk */
   if (Sort != SORT_ORDER)
@@ -693,6 +716,8 @@ int mbox_sync_mailbox (CONTEXT *ctx)
   if ((i = open (tempfile, O_WRONLY | O_EXCL | O_CREAT, 0600)) == -1 ||
       (fp = fdopen (i, "w")) == NULL)
   {
+    if (-1 != i)
+      close (i);
     mutt_error _("Could not create temporary file!");
     goto bail;
   }
@@ -715,15 +740,19 @@ int mbox_sync_mailbox (CONTEXT *ctx)
     goto bail;
   }
 
+    /* save the index of the first changed/deleted message */
+  first = i; 
+  /* where to start overwriting */
+  offset = ctx->hdrs[i]->offset; 
 
-  first = i; /* save the index of the first changed/deleted message */
-  offset = ctx->hdrs[i]->offset; /* where to start overwriting */
   /* the offset stored in the header does not include the MMDF_SEP, so make
    * sure we seek to the correct location
    */
   if (ctx->magic == M_MMDF)
     offset -= strlen (MMDF_SEP);
-
+  else if (ctx->magic == M_KENDRA)
+    offset -= strlen(KENDRA_SEP);
+  
   /* allocate space for the new offsets */
   newOffset = safe_calloc (ctx->msgcount - first, sizeof (struct m_update_t));
 
@@ -741,6 +770,11 @@ int mbox_sync_mailbox (CONTEXT *ctx)
 	if (fputs (MMDF_SEP, fp) == EOF)
 	  goto bail;
       }
+      else if (ctx->magic == M_KENDRA)
+      {
+	if (fputs (KENDRA_SEP, fp) == EOF)
+	  goto bail;
+      }
 
       /* save the new offset for this message.  we add `offset' because the
        * temporary file only contains saved message which are located after
@@ -760,17 +794,28 @@ int mbox_sync_mailbox (CONTEXT *ctx)
       newOffset[i - first].body = ftell (fp) - ctx->hdrs[i]->content->length + offset;
       mutt_free_body (&ctx->hdrs[i]->content->parts);
 
-      if (fputs (ctx->magic == M_MMDF ? MMDF_SEP : "\n", fp) == EOF)
-	goto bail;
+      switch(ctx->magic)
+      {
+	case M_MMDF: 
+	  if(fputs(MMDF_SEP, fp) == EOF) goto bail; 
+	  break;
+	case M_KENDRA:
+	  if(fputs(KENDRA_SEP, fp) == EOF) goto bail;
+	  break;
+	default:
+	  if(fputs("\n", fp) == EOF) goto bail;
+      }
     }
   }
-
+  
   if (fclose (fp) != 0)
   {
-    dprint(1, (debugfile, "mutt_sync_mailbox(): fclose() returned non-zero.\n"));
+    fp = NULL;
+    dprint(1, (debugfile, "mbox_sync_mailbox: fclose() returned non-zero.\n"));
     unlink (tempfile);
     goto bail;
   }
+  fp = NULL;
 
   /* Save the state of this folder. */
   if (stat (ctx->path, &statbuf) == -1)
@@ -788,29 +833,34 @@ int mbox_sync_mailbox (CONTEXT *ctx)
     return (-1);
   }
 
-  fseek (ctx->fp, offset, 0);  /* seek the append location */
-  
-  /* do a sanity check to make sure the mailbox looks ok */
-  if (fgets (buf, sizeof (buf), ctx->fp) == NULL ||
+  if (fseek (ctx->fp, offset, SEEK_SET) != 0 ||  /* seek the append location */
+      /* do a sanity check to make sure the mailbox looks ok */
+      fgets (buf, sizeof (buf), ctx->fp) == NULL ||
       (ctx->magic == M_MBOX && strncmp ("From ", buf, 5) != 0) ||
-      (ctx->magic == M_MMDF && strcmp (MMDF_SEP, buf) != 0))
+      (ctx->magic == M_MMDF && strcmp (MMDF_SEP, buf) != 0) ||
+      (ctx->magic == M_KENDRA && strcmp (KENDRA_SEP, buf) != 0))
   {
-    dprint (1, (debugfile, "mbox_sync_mailbox(): message not in expected position."));
+    dprint (1, (debugfile, "mbox_sync_mailbox: message not in expected position."));
     dprint (1, (debugfile, "\tLINE: %s\n", buf));
     i = -1;
   }
   else
   {
-    fseek (ctx->fp, offset, 0); /* return to proper offset */
-
-    /* copy the temp mailbox back into place starting at the first
-     * change/deleted message
-     */
-    i = mutt_copy_stream (fp, ctx->fp);
-
-    if (ferror (ctx->fp))
+    if (fseek (ctx->fp, offset, SEEK_SET) != 0) /* return to proper offset */
+    {
       i = -1;
+      dprint (1, (debugfile, "mbox_sync_mailbox: fseek() failed\n"));
+    }
+    else
+    {
+      /* copy the temp mailbox back into place starting at the first
+       * change/deleted message
+       */
+      i = mutt_copy_stream (fp, ctx->fp);
 
+      if (ferror (ctx->fp))
+        i = -1;
+    }
     if (i == 0)
     {
       ctx->size = ftell (ctx->fp); /* update the size of the mailbox */
@@ -819,6 +869,7 @@ int mbox_sync_mailbox (CONTEXT *ctx)
   }
 
   fclose (fp);
+  fp = NULL;
   mbox_unlock_mailbox (ctx);
 
   if (fclose (ctx->fp) != 0 || i == -1)
@@ -875,6 +926,10 @@ int mbox_sync_mailbox (CONTEXT *ctx)
 
 bail:  /* Come here in case of disaster */
 
+  /* Disadvantage of using "goto" */
+  if (fp)
+    fclose (fp);
+
   /* this is ok to call even if we haven't locked anything */
   mbox_unlock_mailbox (ctx);
 
@@ -972,15 +1027,19 @@ int mutt_reopen_mailbox (CONTEXT *ctx, int *index_hint)
   switch (ctx->magic)
   {
     case M_MBOX:
-      fseek (ctx->fp, 0, 0);
-      cmp_headers = mbox_strict_cmp_headers;
-      rc = mbox_parse_mailbox (ctx);
-      break;
-
     case M_MMDF:
-      fseek (ctx->fp, 0, 0);
-      cmp_headers = mbox_strict_cmp_headers;
-      rc = mmdf_parse_mailbox (ctx);
+    case M_KENDRA:
+      if (fseek (ctx->fp, 0, SEEK_SET) != 0)
+      {
+        dprint (1, (debugfile, "mutt_reopen_mailbox: fseek() failed\n"));
+        rc = -1;
+      } 
+      else 
+      {
+        cmp_headers = mbox_strict_cmp_headers;
+        rc = ((ctx->magic == M_MBOX) ? mbox_parse_mailbox
+				     : mmdf_parse_mailbox) (ctx);
+      }
       break;
 
     default:
