@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: mh.c,v 1.12 1998/10/13 20:45:32 roessler Exp $";
+static const char rcsid[]="$Id: mh.c,v 1.14 1998/10/15 20:33:44 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -132,7 +132,7 @@ static HEADER *maildir_parse_message(int magic, const char *fname, int is_old)
   if ((f = fopen (fname, "r")) != NULL)
   {
     h = mutt_new_header();
-    h->env = mutt_read_rfc822_header (f, h);
+    h->env = mutt_read_rfc822_header (f, h, 0);
 
     fstat (fileno (f), &st);
     fclose (f);
