@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: mx.c,v 1.17 1998/10/27 09:40:38 roessler Exp $";
+static const char rcsid[]="$Id: mx.c,v 1.18 1998/11/10 21:02:25 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -392,6 +392,8 @@ int mx_set_magic (const char *s)
     DefaultMagic = M_MH;
   else if (strcasecmp (s, "maildir") == 0)
     DefaultMagic = M_MAILDIR;
+  else if (strcasecmp (s, "kendra") == 0)
+    DefaultMagic = M_KENDRA;
   else
     return (-1);
 
