@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: parse.c,v 1.8 1998/10/15 20:33:48 roessler Exp $";
+static const char rcsid[]="$Id: parse.c,v 1.12 1998/11/10 20:25:18 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -517,6 +517,17 @@ BODY *mutt_parse_multipart (FILE *fp, const char *boundary, long end_off, int di
       else if (buffer[2 + blen] == 0)
       {
 	new = mutt_read_mime_header (fp, digest);
+	
+	/*
+	 * Consistency checking - catch
+	 * bad attachment end boundaries
+	 */
+	
+	if(new->offset > end_off)
+	{
+	  mutt_free_body(&new);
+	  break;
+	}
 	if (head)
 	{
 	  last->next = new;
@@ -543,12 +554,14 @@ BODY *mutt_parse_multipart (FILE *fp, const char *boundary, long end_off, int di
 	break;
 
       case TYPEMESSAGE:
-	if (last->subtype &&
-	    (strcasecmp (last->subtype, "rfc822") == 0 ||
-	     strcasecmp (last->subtype, "news") == 0))
+	if (last->subtype)
 	{
-	  fseek (fp, last->offset, 0);
-	  last->parts = mutt_parse_messageRFC822 (fp, last);
+	  fseek (fp, last->offset, SEEK_SET);
+	  if (strcasecmp (last->subtype, "rfc822") == 0 ||
+	      strcasecmp (last->subtype, "news") == 0)
+	    last->parts = mutt_parse_messageRFC822 (fp, last);
+	  else if (strcasecmp (last->subtype, "external-body") == 0)
+	    last->parts = mutt_read_mime_header (fp, 0);
 	}
 	break;
     }
@@ -631,7 +644,7 @@ TimeZones[] =
   { "wst",   8,  0, 0, 0 }, /* Western Australia */
   { "jst",   9,  0, 0, 0 }, /* Japan */
 /*{ "cst",   9, 30, 0, 0 },*/ /* Australian Central Standard Time */
-  { "kst",  10,  0, 0, 0 }, /* Korea */
+  { "kst",   9,  0, 0, 0 }, /* Korea */
   { "nzst", 12,  0, 0, 0 }, /* New Zealand */
   { "nzdt", 13,  0, 0, 0 }, /* New Zealand DST */
   { NULL,    0,  0, 0, 0 }
@@ -644,7 +657,7 @@ TimeZones[] =
  * This routine assumes that `h' has been initialized to 0.  the `timezone'
  * field is optional, defaulting to +0000 if missing.
  */
-static time_t parse_date (char *s, HEADER *h)
+time_t mutt_parse_date (char *s, HEADER *h)
 {
   int count = 0;
   char *t;
@@ -976,14 +989,14 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
 	  safe_free((void **)&e->date);
 	  e->date = safe_strdup(p);
 	  if (hdr)
-	    hdr->date_sent = parse_date (p, hdr);
+	    hdr->date_sent = mutt_parse_date (p, hdr);
 	  matched = 1;
 	}
 	break;
 
       case 'e':
 	if (!strcasecmp ("xpires", line + 1) &&
-	    hdr && parse_date (p, hdr) < time (NULL))
+	    hdr && mutt_parse_date (p, NULL) < time (NULL))
 	  hdr->expired = 1;
 	break;
 
@@ -1071,7 +1084,7 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
 	    char *d = strchr (p, ';');
 
 	    if (d)
-	      hdr->received = parse_date (d + 1, NULL);
+	      hdr->received = mutt_parse_date (d + 1, NULL);
 	  }
 	}
 	break;
