@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: pop.c,v 1.7 1998/10/15 20:33:55 roessler Exp $";
+static const char rcsid[]="$Id: pop.c,v 1.8 1998/11/09 10:59:41 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -208,7 +208,7 @@ void mutt_fetchPopMail (void)
   
   snprintf (msgbuf, sizeof (msgbuf),
 	    msgs > 1 ? _("Reading %d new message (%d bytes)...") :
-		    ("Reading %d new messages (%d bytes)..."), msgs - last, bytes);
+		    _("Reading %d new messages (%d bytes)..."), msgs - last, bytes);
   mutt_message (msgbuf);
 
   for (i = last + 1 ; i <= msgs ; i++)
