@@ -1,4 +1,4 @@
-/* $Id: protos.h,v 1.26 1998/10/27 09:41:16 roessler Exp $ */
+/* $Id: protos.h,v 1.29 1998/11/09 11:52:26 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -95,6 +95,7 @@ ATTACHPTR **mutt_gen_attach_list (BODY *, ATTACHPTR **, short *, short *, int, i
 time_t mutt_local_tz (void);
 time_t mutt_mktime (struct tm *, int);
 time_t is_from (const char *, char *, size_t);
+time_t mutt_parse_date (char *, HEADER *);
 
 const char *mutt_attach_fmt (
 	char *dest,
@@ -116,6 +117,7 @@ char *mutt_get_parameter (const char *, PARAMETER *);
 #ifdef _PGPPATH
 char *mutt_pgp_hook (ADDRESS *);
 #endif /* _PGPPATH */
+char *mutt_make_date (char *, size_t);
 char *mutt_quote_filename(const char *);
 char *mutt_read_line (char *, size_t *, FILE *, int *);
 char *mutt_strlower (char *);
@@ -272,7 +274,6 @@ int mutt_write_mime_body (BODY *, FILE *);
 int mutt_write_mime_header (BODY *, FILE *);
 int mutt_write_rfc822_header (FILE *, ENVELOPE *, BODY *, int);
 int mutt_yesorno (const char *, int);
-void mutt_cache_index_colors(CONTEXT *);
 void mutt_set_header_color(CONTEXT *, HEADER *);
 int mutt_save_confirm (const char  *, struct stat *);
 
