@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: score.c,v 1.4 1998/10/15 20:34:04 roessler Exp $";
+static const char rcsid[]="$Id: score.c,v 1.5 1998/11/09 11:15:32 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -54,7 +54,9 @@ void mutt_check_rescore (CONTEXT *ctx)
     for (i = 0; i < ctx->msgcount; i++)
       mutt_score_message (ctx->hdrs[i]);
 
-    mutt_cache_index_colors (ctx);
+    /* force re-caching of index colors */
+    for (i = 0; ctx && i < ctx->msgcount; i++)
+      ctx->hdrs[i]->pair = 0;
 
     unset_option (OPTNEEDRESCORE);
   }
