@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: send.c,v 1.21 1998/10/28 21:32:13 roessler Exp $";
+static const char rcsid[]="$Id: send.c,v 1.22 1998/11/09 10:46:48 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -462,9 +462,8 @@ static int fetch_recips (ENVELOPE *out, ENVELOPE *in, int flags)
 
     if ((flags & SENDGROUPREPLY) && !in->mail_followup_to)
     {
-      if(!mutt_addr_is_user(in->to))
-	rfc822_append (&out->cc, in->to);
-      
+      /* if(!mutt_addr_is_user(in->to)) */
+      rfc822_append (&out->cc, in->to);
       rfc822_append (&out->cc, in->cc);
     }
   }
