@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: sendlib.c,v 1.28 1998/10/27 09:41:18 roessler Exp $";
+static const char rcsid[]="$Id: sendlib.c,v 1.30 1998/11/10 21:02:27 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -1155,7 +1155,7 @@ BODY *mutt_remove_multipart (BODY *b)
   return b;
 }
 
-static char *mutt_make_date (char *s, size_t len)
+char *mutt_make_date (char *s, size_t len)
 {
   time_t t = time (NULL);
   struct tm *l = gmtime(&t);
@@ -1911,7 +1911,7 @@ int mutt_write_fcc (const char *path, HEADER *hdr, const char *msgid, int post,
   /* We need to add a Content-Length field to avoid problems where a line in
    * the message body begins with "From "   
    */
-  if (f.magic == M_MMDF || f.magic == M_MBOX)
+  if (f.magic == M_MMDF || f.magic == M_MBOX || f.magic == M_KENDRA)
   {
     mutt_mktemp (tempfile);
     if ((tempfp = safe_fopen (tempfile, "w+")) == NULL)
